diff --git a/config/c-library.m4 b/config/c-library.m4
index 9c2207b03d..34b25081a6 100644
--- a/config/c-library.m4
+++ b/config/c-library.m4
@@ -177,7 +177,7 @@ AC_DEFUN([PGAC_STRUCT_ADDRINFO],
 # handle ll, q, and I64.  The result is in shell variable
 # LONG_LONG_INT_MODIFIER.
 #
-# MinGW uses '%I64d', though gcc throws an warning with -Wall,
+# MinGW uses '%I64d', though gcc throws a warning with -Wall,
 # while '%lld' doesn't generate a warning, but doesn't work.
 #
 AC_DEFUN([PGAC_FUNC_SNPRINTF_LONG_LONG_INT_MODIFIER],
diff --git a/doc/src/sgml/func.sgml b/doc/src/sgml/func.sgml
index 2f59af25a6..bd9f080895 100644
--- a/doc/src/sgml/func.sgml
+++ b/doc/src/sgml/func.sgml
@@ -20090,7 +20090,7 @@ postgres=# SELECT * FROM pg_walfile_name_offset(pg_stop_backup());
     included in the result set. The default is to exclude them
     (<literal>false</literal>), but including them can be useful when
     <parameter>missing_ok</parameter> is <literal>true</literal>, to distinguish an
-    empty directory from an non-existent directory.
+    empty directory from a non-existent directory.
    </para>
 
    <indexterm>
diff --git a/src/backend/access/gin/ginvacuum.c b/src/backend/access/gin/ginvacuum.c
index 398532d80b..8b08b46ff6 100644
--- a/src/backend/access/gin/ginvacuum.c
+++ b/src/backend/access/gin/ginvacuum.c
@@ -381,7 +381,7 @@ ginVacuumPostingTreeLeaves(GinVacuumState *gvs, BlockNumber blkno, bool isRoot)
 
 		/*
 		 * All subtree is empty - just return true to indicate that parent
-		 * must do a cleanup. Unless we are ROOT an there is way to go upper.
+		 * must do a cleanup. Unless we are ROOT and there is way to go upper.
 		 */
 
 		if (hasEmptyChild && !hasNonEmptyChild && !isRoot)
diff --git a/src/backend/catalog/aclchk.c b/src/backend/catalog/aclchk.c
index 0648539796..9150f8c62d 100644
--- a/src/backend/catalog/aclchk.c
+++ b/src/backend/catalog/aclchk.c
@@ -5280,7 +5280,7 @@ pg_extension_ownercheck(Oid ext_oid, Oid roleid)
 }
 
 /*
- * Ownership check for an publication (specified by OID).
+ * Ownership check for a publication (specified by OID).
  */
 bool
 pg_publication_ownercheck(Oid pub_oid, Oid roleid)
diff --git a/src/backend/commands/cluster.c b/src/backend/commands/cluster.c
index 5d481dd50d..125002e75e 100644
--- a/src/backend/commands/cluster.c
+++ b/src/backend/commands/cluster.c
@@ -1538,7 +1538,7 @@ finish_heap_swap(Oid OIDOldHeap, Oid OIDNewHeap,
 						frozenXid, cutoffMulti, mapped_tables);
 
 	/*
-	 * If it's a system catalog, queue an sinval message to flush all
+	 * If it's a system catalog, queue a sinval message to flush all
 	 * catcaches on the catalog when we reach CommandCounterIncrement.
 	 */
 	if (is_system_catalog)
diff --git a/src/backend/executor/instrument.c b/src/backend/executor/instrument.c
index a2d9381ba1..86252cee1f 100644
--- a/src/backend/executor/instrument.c
+++ b/src/backend/executor/instrument.c
@@ -49,7 +49,7 @@ InstrAlloc(int n, int instrument_options)
 	return instr;
 }
 
-/* Initialize an pre-allocated instrumentation structure. */
+/* Initialize a pre-allocated instrumentation structure. */
 void
 InstrInit(Instrumentation *instr, int instrument_options)
 {
diff --git a/src/backend/libpq/pqformat.c b/src/backend/libpq/pqformat.c
index 30145b96ec..1c7e99019d 100644
--- a/src/backend/libpq/pqformat.c
+++ b/src/backend/libpq/pqformat.c
@@ -100,7 +100,7 @@ pq_beginmessage(StringInfo buf, char msgtype)
 
  *		pq_beginmessage_reuse - initialize for sending a message, reuse buffer
  *
- * This requires the buffer to be allocated in an sufficiently long-lived
+ * This requires the buffer to be allocated in a sufficiently long-lived
  * memory context.
  * --------------------------------
  */
diff --git a/src/backend/nodes/readfuncs.c b/src/backend/nodes/readfuncs.c
index 068db353d7..41bfb61e24 100644
--- a/src/backend/nodes/readfuncs.c
+++ b/src/backend/nodes/readfuncs.c
@@ -77,7 +77,7 @@
 	token = pg_strtok(&length);		/* get field value */ \
 	local_node->fldname = pg_strtouint64(token, NULL, 10)
 
-/* Read an long integer field (anything written as ":fldname %ld") */
+/* Read a long integer field (anything written as ":fldname %ld") */
 #define READ_LONG_FIELD(fldname) \
 	token = pg_strtok(&length);		/* skip :fldname */ \
 	token = pg_strtok(&length);		/* get field value */ \
diff --git a/src/backend/utils/adt/nabstime.c b/src/backend/utils/adt/nabstime.c
index ec85795827..fae97135db 100644
--- a/src/backend/utils/adt/nabstime.c
+++ b/src/backend/utils/adt/nabstime.c
@@ -694,7 +694,7 @@ reltime2tm(RelativeTime time, struct pg_tm *tm)
 
 
 /*
- *		tintervalin		- converts an tinterval string to internal format
+ *		tintervalin		- converts a tinterval string to internal format
  */
 Datum
 tintervalin(PG_FUNCTION_ARGS)
diff --git a/src/backend/utils/cache/relcache.c b/src/backend/utils/cache/relcache.c
index 9ee78f885f..b73db2970d 100644
--- a/src/backend/utils/cache/relcache.c
+++ b/src/backend/utils/cache/relcache.c
@@ -2350,7 +2350,7 @@ RelationDestroyRelation(Relation relation, bool remember_tupdesc)
  *	 NB: when rebuilding, we'd better hold some lock on the relation,
  *	 else the catalog data we need to read could be changing under us.
  *	 Also, a rel to be rebuilt had better have refcnt > 0.  This is because
- *	 an sinval reset could happen while we're accessing the catalogs, and
+ *	 a sinval reset could happen while we're accessing the catalogs, and
  *	 the rel would get blown away underneath us by RelationCacheInvalidate
  *	 if it has zero refcnt.
  *
diff --git a/src/bin/pgbench/t/001_pgbench_with_server.pl b/src/bin/pgbench/t/001_pgbench_with_server.pl
index 0c23d2fc58..3c663d1272 100644
--- a/src/bin/pgbench/t/001_pgbench_with_server.pl
+++ b/src/bin/pgbench/t/001_pgbench_with_server.pl
@@ -474,7 +474,7 @@ SELECT LEAST(:i, :i, :i, :i, :i, :i, :i, :i, :i, :i, :i);
 		0,
 		[ qr{cannot coerce boolean to int} ],
 		q{\set i TRUE + 2} ],
-	[ 'set not an double',
+	[ 'set not a double',
 		0,
 		[ qr{cannot coerce boolean to double} ],
 		q{\set d ln(TRUE)} ],
